import React from 'react';
import { LinkIcon } from '@heroicons/react/24/outline';
import { type RedeSocial } from '../../api';

interface SocialMediaComponentProps {
  redesSociais: RedeSocial[] | null;
  isLoading: boolean;
}

const SocialMediaComponent: React.FC<SocialMediaComponentProps> = ({ 
  redesSociais, 
  isLoading 
}) => {
  return (
    <div className="bg-white/95 backdrop-blur-sm rounded-xl shadow-lg hover:shadow-xl transform hover:scale-[1.02] transition-all duration-200 p-6">
      <div className="flex items-center mb-6">
        <LinkIcon className="h-8 w-8 text-orange-600 mr-3" />
        <h2 className="text-2xl font-bold text-gray-900">Redes Sociais</h2>
      </div>

      {isLoading ? (
        <div className="flex items-center justify-center h-32">
          <div className="animate-spin rounded-full h-8 w-8 border-4 border-orange-600 border-t-transparent"></div>
        </div>
      ) : redesSociais && redesSociais.length > 0 ? (
        <div className="space-y-3">
          {redesSociais.map((redeSocial: RedeSocial, index: number) => (
            <div key={`${redeSocial.idCandidato}-${redeSocial.rede}-${index}`} className="border border-gray-200 rounded-lg p-3 hover:bg-gray-50 transition-colors">
              <div className="flex items-center justify-between">
                <div className="flex-1">
                  <div className="flex items-center mb-2">
                    <span className="font-semibold text-gray-900 mr-2">{redeSocial.rede}</span>
                    <span className="text-sm text-gray-500">({redeSocial.ano})</span>
                  </div>
                  <a 
                    href={redeSocial.link} 
                    target="_blank" 
                    rel="noopener noreferrer"
                    className="text-blue-600 hover:text-blue-800 text-sm break-all transition-colors"
                  >
                    {redeSocial.link}
                  </a>
                </div>
              </div>
            </div>
          ))}
        </div>
      ) : (
        <div className="text-center text-gray-500 py-8">
          Nenhuma rede social encontrada
        </div>
      )}
    </div>
  );
};

export default SocialMediaComponent;
